"""``DuIvyTools`` package for analysis of GMX MD results files. Written by Charles Hahn.

Python modules
----------------
The package consists of the following Python modules:
* DIT : the CLI application.
* XPM  : module to process XPM files.
* XVG  : module to process XVG files.

"""

from .DIT import *
from .XPM import *
from .XVG import *

